# pybezier

`pybezier` is a simple Python libarary for manipulating Bézier curves.

## Installation

```bash
pip install pybezier
```

## Dependencies

* Python >= 3.10
* [NumPy](https://pypi.org/project/numpy/)

## Usage

See the [examples](https://github.com/TobiaMarcucci/pybezier/tree/main/examples) folder.


## License

`pybezier` carries an MIT License.
